@@ -1,5 +1,6 @@
 
 ##' Impute the Data Without Consideration of Conditions.
+##'
 ##' This function is to impute missing data by one of the eight
 ##' methods without the condition. When the condtions are imported,
 ##' they are then romoved from the data frame, and then the imputation
@@ -175,6 +176,7 @@ singleimputation = function(dat, method, vartype, cond) {
 
 ##' Impute the missing data with the method selected under the
 ##' condition.
+##'
 ##' This function provides eight methods for imputation with
 ##' categorical varaibles as conditions.
 ##'
@@ -274,7 +276,7 @@ imputation = function(origdata, method, vartype, missingpct, condition=NULL){
 					}
 				}
 				if (!is.null(dat)) {
-					res = data.frame(dat,row_number=1:nrow(origdata))
+					res = data.frame(dat,row_number=1:nrow(dat))
 				} else {res=NULL}
 			} else {
 				dat = ddply(data.frame(origdata,row_number_2011=1:nrow(origdata)),
@@ -423,6 +425,7 @@ imputation = function(origdata, method, vartype, missingpct, condition=NULL){
 
 
 ##' The Main Window of Missing Data GUI.
+##'
 ##' This function is to open the missing data GUI. The widgets shown
 ##' in the GUI include: a table of all variables in the dataset, a
 ##' checkbox group of categorical variables to condition on, a table
@@ -575,6 +578,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 				No_of_Case=No_of_Case,
 				Percent=round(No_of_Case/length(tmpdat)*100,1))
 		}
+		missingsummary = missingsummary[order(missingsummary$No_of_miss_by_case, decreasing=FALSE),]
 
 		NumSumforMisVal <- gwindow("Numeric Summary for Missing Values", visible = T, width = 350, height = 300, parent = combo1)
 		groupN1 = ggroup(cont = NumSumforMisVal, horizontal = FALSE, expand = TRUE)
@@ -605,7 +609,6 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 		imp_method = svalue(gr142)
 		graphtype = svalue(gr143)
 		n = length(name_select)
-		Missing = rep(0, nrow(dataset))
 		cond = check123[svalue(check123,index=T)]
 		if (length(cond)==0) cond = NULL
 		if (imp_method=='Below 10%') cond = NULL
@@ -629,7 +632,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
         }
 
 
-		dat = imputation(origdata=dataset[,c(gt11[name_select,2],cond)],
+		dat = imputation(origdata=dataset[,c(gt11[name_select,2],cond),drop=FALSE],
 			method=imp_method, vartype=as.character(gt11[name_select,3]),
 			missingpct=as.numeric(as.character(gt11[name_select,4])),
 			condition=cond)
@@ -639,15 +642,15 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 			eval(parse(text=paste("dat[,i]=as.",as.character(gt11[name_select,3])[i],"(as.character(dat[,i]))",sep="")))
 		}
 		if (colorby=='Missing on Selected Variables') {
-			Missing <<- !complete.cases(dataset[,gt11[name_select,2]])
+			Missing <- !complete.cases(dataset[,gt11[name_select,2]])
 		} else {
 			if (colorby=='Missing Any Variables') {
-				Missing <<- !complete.cases(dataset)
+				Missing <- !complete.cases(dataset)
 			} else {
-				Missing <<- !complete.cases(dataset[,colorby])
+				Missing <- !complete.cases(dataset[,colorby])
 			}
 		}
-		Missing <<- Missing[dat[,ncol(dat)]]
+		Missing <- Missing[dat[,ncol(dat)]]
 
 		if (graphtype=="Histogram/Barchart") {
 			for (i in 1:n) {
@@ -671,41 +674,6 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 						fill=Missing, xlab=names(tmpdat)[i])+coord_flip())
 				}
 			}
-			# svalue(text16) = capture.output(cat("
-	# dat = imputation(origdata=dataset, method=imp_method,
-		# vartype=class(dataset), condition=cond,
-		# missingpct=sapply(dataset,function(x){sum(is.na(x))/length(x)}))
-	# colnames(dat)[1:(2*n)]=c(colnames(dataset),
-		# paste('Missing', colnames(dataset), sep='_'))
-	# if (colorby=='Missing on Selected Variables') {
-		# Missing = dat[,ncol(dat)]
-	# } else {
-		# if (colorby=='Missing Any Variables') {
-			# Missing = !complete.cases(dataset)
-		# } else {
-			# Missing = !complete.cases(dataset[,colorby])
-		# }
-	# }
-
-	# for (i in 1:n) {
-		# if (is.numeric(dat[,i])) {
-			# tmpdat = data.frame(dat,Missing=Missing)
-			# print(qplot(tmpdat[,i],data=tmpdat,geom='histogram',
-				# fill=Missing, xlab=names(tmpdat)[i]))
-		# }
-		# if (is.character(dat[,i])) {
-			# tmpdat = data.frame(dat,Missing=Missing)
-			# print(qplot(tmpdat[,i],data=tmpdat,geom='histogram',
-				# fill=Missing, xlab=names(tmpdat)[i])+coord_flip())
-		# }
-		# if (is.factor(dat[,i]) &
-		# as.numeric(as.character(gt11[name_select,4]))[i]<1) {
-			# tmpdat = data.frame(dat,Missing=Missing)
-			# print(qplot(tmpdat[,i],data=tmpdat,geom='histogram',
-				# fill=Missing, xlab=names(tmpdat)[i])+coord_flip())
-		# }
-	# }
-			# "))
 		}
 		if (graphtype=="Spinogram/Spineplot") {
 			for (i in 1:n) {
@@ -727,41 +695,6 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 						fill=Missing, position="fill", xlab=names(tmpdat)[i])+coord_flip())
 				}
 			}
-			# svalue(text16) = capture.output(cat("
-	# dat = imputation(origdata=dataset, method=imp_method,
-		# vartype=class(dataset), condition=cond,
-		# missingpct=sapply(dataset,function(x){sum(is.na(x))/length(x)}))
-	# colnames(dat)[1:(2*n)]=c(colnames(dataset),
-		# paste('Missing', colnames(dataset), sep='_'))
-	# if (colorby=='Missing on Selected Variables') {
-		# Missing = dat[,ncol(dat)]
-	# } else {
-		# if (colorby=='Missing Any Variables') {
-			# Missing = !complete.cases(dataset)
-		# } else {
-			# Missing = !complete.cases(dataset[,colorby])
-		# }
-	# }
-
-	# for (i in 1:n) {
-		# if (is.numeric(dat[,i])) {
-			# tmpdat = data.frame(dat,Missing=Missing)
-			# print(qplot(tmpdat[,i],data=tmpdat,geom='histogram',
-				# fill=Missing, position='fill', xlab=names(tmpdat)[i]))
-		# }
-		# if (is.character(dat[,i])) {
-			# tmpdat = data.frame(dat,Missing=Missing)
-			# print(qplot(tmpdat[,i],data=tmpdat,geom='histogram',
-				# fill=Missing, position='fill', xlab=names(tmpdat)[i])+coord_flip())
-		# }
-		# if (is.factor(dat[,i]) &
-		# as.numeric(as.character(gt11[name_select,4]))[i]<1) {
-			# tmpdat = data.frame(dat,Missing=Missing)
-			# print(qplot(tmpdat[,i],data=tmpdat,geom='histogram',
-				# fill=Missing, position='fill', xlab=names(tmpdat)[i])+coord_flip())
-		# }
-	# }
-			# "))
 		}
 		if (graphtype=="Pairwise Plots") {
 			if (n > 5) {
@@ -776,42 +709,15 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 				print(qplot(dat[,1],dat[,2], color=Missing, geom='jitter',alpha=I(0.7),
 					size=I(3),xlab=colnames(dat)[1],ylab=colnames(dat)[2]))
 			} else {
-			print(ggpairs(dat[,1:n],
+			dat$Missings=factor(Missing)
+			print(ggpairs(dat,columns=1:n,
 				upper = "blank",
 				lower = list(continuous = "points", discrete = "ratio",
 					aes_string = aes_string(position="position_jitter(width=1)")),
 				diag = list(continuous = "bar", discrete = "bar"),
-				color="Missing", fill="Missing",alpha=I(0.5)) )
+				color="Missings", fill="Missings",alpha=I(0.5)) )
 			# ggpairs(iris,colour=species)
 			}
-			# svalue(text16) = capture.output(cat("
-	# dat = imputation(origdata=dataset, method=imp_method,
-		# vartype=class(dataset), condition=cond,
-		# missingpct=sapply(dataset,function(x){sum(is.na(x))/length(x)}))
-	# colnames(dat)[1:(2*n)]=c(colnames(dataset),
-		# paste('Missing', colnames(dataset), sep='_'))
-	# if (colorby=='Missing on Selected Variables') {
-		# Missing = dat[,ncol(dat)]
-	# } else {
-		# if (colorby=='Missing Any Variables') {
-			# Missing = !complete.cases(dataset)
-		# } else {
-			# Missing = !complete.cases(dataset[,colorby])
-		# }
-	# }
-
-	# if (n==2) {
-		# print(qplot(dat[,1],dat[,2], color=Missing, geom='jitter',alpha=I(0.7),
-			# size=I(3),xlab=colnames(dat)[1],ylab=colnames(dat)[2]))
-	# } else {
-		# print(ggpairs(dat[,1:n],
-			# upper = 'blank',
-			# lower = list(continuous = 'points', discrete = 'ratio',
-				# aes_string = aes_string(position='position_jitter(width=1)')),
-			# diag = list(continuous = 'bar', discrete = 'bar'),
-			# color='Missing', fill='Missing',alpha=I(0.5)) )
-	# }
-			# "))
 		}
 		if (graphtype=="Parallel Coordinates") {
 			if (n==1) {
@@ -825,28 +731,8 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 				return()
 			}
 			glay15[1, 1, expand = TRUE] = ggraphics(container = glay15, expand = TRUE)
-			print(ggpcp(dat[,1:n])+geom_line(aes(colour=Missing))+
-				geom_point(subset=dat[Missing=='Missing',1:n],colour='blue'))
-
-			# svalue(text16) = capture.output(cat("
-	# dat = imputation(origdata=dataset, method=imp_method,
-		# vartype=class(dataset), condition=cond,
-		# missingpct=sapply(dataset,function(x){sum(is.na(x))/length(x)}))
-	# colnames(dat)[1:(2*n)]=c(colnames(dataset),
-		# paste('Missing', colnames(dataset), sep='_'))
-	# if (colorby=='Missing on Selected Variables') {
-		# Missing = dat[,ncol(dat)]
-	# } else {
-		# if (colorby=='Missing Any Variables') {
-			# Missing = !complete.cases(dataset)
-		# } else {
-			# Missing = !complete.cases(dataset[,colorby])
-		# }
-	# }
-
-	# print(ggpcp(dat[,1:n])+geom_line(aes(colour=Missing))+
-		# geom_point(subset=dat[Missing=='Missing',1:n],colour='blue'))
-			# "))
+			dat$Missing=Missing
+			print(ggpcp(dat,vars=names(dat)[1:n])+geom_line(aes(colour=Missing)))
 		}
 
 	}
@@ -894,7 +780,6 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 		imp_method = svalue(gr142)
 		graphtype = svalue(gr143)
 		n = length(name_select)
-		Missing = rep(0, nrow(dataset))
 		cond = check123[svalue(check123,index=T)]
 		if (length(cond)==0) cond = NULL
 		if (imp_method=='Below 10%') cond = NULL
@@ -927,15 +812,15 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 			eval(parse(text=paste("dat[,i]=as.",as.character(gt11[name_select,3])[i],"(as.character(dat[,i]))",sep="")))
 		}
 		if (colorby=='Missing on Selected Variables') {
-			Missing <<- !complete.cases(dataset[,gt11[name_select,2]])
+			Missing <- !complete.cases(dataset[,gt11[name_select,2]])
 		} else {
 			if (colorby=='Missing Any Variables') {
-				Missing <<- !complete.cases(dataset)
+				Missing <- !complete.cases(dataset)
 			} else {
-				Missing <<- !complete.cases(dataset[,colorby])
+				Missing <- !complete.cases(dataset[,colorby])
 			}
 		}
-		Missing <<- Missing[dat[,ncol(dat)]]
+		Missing <- Missing[dat[,ncol(dat)]]
 
 		if (graphtype=="Histogram/Barchart") {
 			savename = gfile(type="save")
@@ -999,12 +884,13 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 				print(qplot(dat[,1],dat[,2], color=Missing, geom='jitter',alpha=I(0.7),
 					size=I(3),xlab=colnames(dat)[1],ylab=colnames(dat)[2]))
 			} else {
-			print(ggpairs(dat[,1:n],
+			dat$Missings=factor(Missing)
+			print(ggpairs(dat,columns=1:n,
 				upper = "blank",
 				lower = list(continuous = "points", discrete = "ratio",
 					aes_string = aes_string(position="position_jitter(width=1)")),
 				diag = list(continuous = "bar", discrete = "bar"),
-				color="Missing", fill="Missing",alpha=I(0.5)) )
+				color="Missings", fill="Missings",alpha=I(0.5)) )
 			# ggpairs(iris,colour=species)
 			}
 			dev.off()
@@ -1022,8 +908,9 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 			}
 			savename = gfile(type="save")
 			png(filename = paste(savename,'_pcp.png',sep=''),width = (n+2), height = 4, units = "in", res=90)
-			print(ggpcp(dat[,1:n])+geom_line(aes(colour=Missing))+
-				geom_point(subset=dat[Missing=='Missing',1:n],colour='blue'))
+			dat$Missing=Missing
+			print(ggpcp(dat,vars=names(dat)[1:n])+geom_line(aes(colour=Missing)))
+			#	+ geom_point(subset=dat[Missing,1:n],colour='blue'))
 			dev.off()
 		}
 
@@ -1114,7 +1001,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
     gt21 = gtable(nametable, multiple = T, container = group22,
         expand = TRUE, chosencol = 2)
     addHandlerMouseMotion(gt21, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This table displays all variables in the data set and
 	reports the type and the percentage of missing values
 	for each variable.\n
@@ -1127,7 +1014,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	check223 = gcheckboxgroup(nametable$Variables[nametable$Class %in%
 		c('factor','logical','character')], container=group22, use.table=TRUE)
 	addHandlerMouseMotion(check223, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This list displays all categorical variables.
 	We can make multiple selection on them.\n
 	Once we select one or more variables, the data
@@ -1145,7 +1032,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	radio225 = gtable(data.frame(`Color by the missing of`=
 		c('Missing Any Variables','Missing on Selected Variables',nametable[vNApct>0,2])),
 		container = group24, expand=TRUE, handler=function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This list displays all variables which have
 	missing values.\n
 	If the user chooses one of them, the color of the
@@ -1164,7 +1051,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	variable if the list is quite long."))
 	})
 	addHandlerMouseMotion(radio225, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This list displays all variables which have
 	missing values.\n
 	If the user chooses one of them, the color of the
@@ -1187,7 +1074,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	gr242 = gradio(c('Below 10%','Median','Mean','Random value',
 		'Regression','Nearest neighbor','Multiple Imputation','Mode'),
 		container = gframe242, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This list displays all the imputation methods.\n
 	We can only select one of them.\n
 	(1)'Below 10%' means NA's of one variable will
@@ -1224,7 +1111,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	(omit NA's)."))
 	})
 	addHandlerMouseMotion(gr242, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This list displays all the imputation methods.\n
 	We can only select one of them.\n
 	(1)'Below 10%' means NA's of one variable will
@@ -1265,7 +1152,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	gr243 = gradio(c('Histogram/Barchart','Spinogram/Spineplot','Pairwise Plots',
 		'Parallel Coordinates'), container = gframe243,
 		handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This frame shows all plots we can make.\n
 	(1)'Histogram/Barchart' will display histograms
 	(numeric variables) and barcharts(categorical
@@ -1282,7 +1169,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	coordinates plot for the selected variables."))
 	})
 	addHandlerMouseMotion(gr243, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	This frame shows all plots we can make.\n
 	(1)'Histogram/Barchart' will display histograms
 	(numeric variables) and barcharts(categorical
@@ -1302,7 +1189,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	group244 = ggroup(horizontal = FALSE, container = group24)
 	gb245 = gbutton('Numeric summary', container = group244,
         handler = function(h,...){
-			svalue(text25) = capture.output(cat("
+			if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will create another window
 	which presents the numeric summaries for missing
 	values.\n
@@ -1316,7 +1203,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	as well as the percentage of those cases."))
 		})
 	addHandlerMouseMotion(gb245, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will create another window
 	which presents the numeric summaries for missing
 	values.\n
@@ -1332,7 +1219,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 
 	gb244 = gbutton("Plot", container = group244,
         handler = function(h,...){
-			svalue(text25) = capture.output(cat("
+			if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will draw a plot based on
 	the options the user chooses.\n
 	All the n variables the user selected should be
@@ -1341,7 +1228,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	first 5	variables are displayed."))
 		})
 	addHandlerMouseMotion(gb244, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will draw a plot based on
 	the options the user chooses.\n
 	All the n variables the user selected should be
@@ -1352,7 +1239,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 
 	gb246 = gbutton('Export the data', container = group244,
         handler = function(h,...){
-			svalue(text25) = capture.output(cat("
+			if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will export the imputed data
 	based on the options the user chooses.\n
 	A user can define the file name for the exported
@@ -1366,7 +1253,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	original dataset."))
 		})
 	addHandlerMouseMotion(gb246, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will export the imputed data
 	based on the options the user chooses.\n
 	A user can define the file name for the exported
@@ -1382,14 +1269,14 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 
 	gb248 = gbutton('Save the plot', container = group244,
         handler = function(h,...){
-			svalue(text25) = capture.output(cat("
+			if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will save the plot(s) to png
 	file(s) based on the options the user chooses.\n
 	A user can define the file name for the plot, and
 	the graph type will be suffixed automatically."))
 		})
 	addHandlerMouseMotion(gb248, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will save the plot(s) to png
 	file(s) based on the options the user chooses.\n
 	A user can define the file name for the plot, and
@@ -1398,11 +1285,11 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 
 	gb247 = gbutton('Quit', container = group244,
         handler = function(h,...){
-			svalue(text25) = capture.output(cat("
+			if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will destroy the main window."))
 		})
 	addHandlerMouseMotion(gb247, handler = function(h,...){
-		svalue(text25) = capture.output(cat("
+		if (exists('text25')) svalue(text25) = capture.output(cat("
 	Clicking this button will destroy the main window."))
 	})
 
@@ -1415,21 +1302,21 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 	# group2101 = ggroup(cont = group21)
 	# text26 = gtext(text = NULL, height = 50, container = group2101, expand=TRUE)
 	# addHandlerKeystroke(text26, handler = function(h,...){
-		# svalue(text25) = capture.output(cat("
+		# if (exists('text25')) svalue(text25) = capture.output(cat("
 	# The code for the plots is texted here. Currently it
 	# cannot be executed directly. The user need to import
 	# the dataset and use the correct paramter to make a
 	# similar plot."))
 	# })
 	# addHandlerClicked(text26, handler = function(h,...){
-		# svalue(text25) = capture.output(cat("
+		# if (exists('text25')) svalue(text25) = capture.output(cat("
 	# The code for the plots is texted here. Currently it
 	# cannot be executed directly. The user need to import
 	# the dataset and use the correct paramter to make a
 	# similar plot."))
 	# })
 	# addHandlerMouseMotion(text26, handler = function(h,...){
-		# svalue(text25) = capture.output(cat("
+		# if (exists('text25')) svalue(text25) = capture.output(cat("
 	# The code for the plots is texted here. Currently it
 	# cannot be executed directly. The user need to import
 	# the dataset and use the correct paramter to make a
@@ -1441,6 +1328,7 @@ WatchMissingValues = function(h, data=NULL, gt=NULL, ...){
 
 
 ##' The Starting of Missing Data GUI.
+##'
 ##' This function starts an open-files GUI, allowing 1) selecting one
 ##' or more data files; 2)opening the main missing-data GUI for one
 ##' data file. The missing data GUI consists of two tabs. In the
@@ -1502,6 +1390,7 @@ MissingDataGUI = function(data=NULL) {
 
 
 ##' West Pacific Tropical Atmosphere Ocean Data, 1993 & 1997.
+##'
 ##' Real-time data from moored ocean buoys for improved detection,
 ##' understanding and prediction of El Ni'o and La Ni'a.
 ##'
@@ -1544,6 +1433,7 @@ NULL
 
 ##' The Behavioral Risk Factor Surveillance System (BRFSS) Survey
 ##' Data, 2009.
+##'
 ##' The data is a subset of the 2009 survey from BRFSS, an ongoing
 ##' data collection program designed to measure behavioral risk
 ##' factors for the adult population (18 years of age or older) living
